@@ -3,7 +3,7 @@ package Acme::CPANAuthors::Japanese;
 use strict;
 use warnings;
 
-our $VERSION = '0.161210';
+our $VERSION = '0.180304';
 
 use Acme::CPANAuthors::Register (
     ABUI      => 'DAISUKE ABUI',
@@ -29,6 +29,7 @@ use Acme::CPANAuthors::Register (
     AKXLIX    => 'azuma, kuniyuki',
     AMARISAN  => 'Ryoji Tanida',
     AMIMOTO   => 'Aki Mimoto',
+    ANATOFUZ  => 'Takahiro SHIMIZU',
     ANAZAWA   => 'Ryo Anazawa',
     ANNELI    => 'Yuki Izumi',
     ANZUSAN   => 'masashi nakajima',
@@ -151,6 +152,7 @@ use Acme::CPANAuthors::Register (
     ICHI      => 'Takuya Ichikawa',
     ICHIGOTAK => 'ichigotake',
     IHARA     => 'Ikuhiro IHARA',
+    IIDAATCNT => 'MASAKATSU IIDA',
     IIZUKA    => 'Nao Iizuka',
     IKEBE     => 'IKEBE Tomohiro',
     IKHRNET   => 'Tatsuya Ikehara',
@@ -193,6 +195,7 @@ use Acme::CPANAuthors::Register (
     KAZUPH    => 'Kazuhiro Homma',
     KAZYAM    => 'Kazumasa Yamamoto',
     KEISUKE   => 'Keisuke Kuramata',
+    KEND      => 'Kenji Doi',
     KENJIRO   => 'Kenjiro Hirakawa',
     KENSHIN   => 'Kenshin YAMADA',
     KENTARO   => 'Kentaro Kuribayashi',
@@ -219,9 +222,11 @@ use Acme::CPANAuthors::Register (
     KOBAYASI  => 'Hiroyuki Kobayasi',
     KOGA      => 'Seiki Koga',
     KOJIMAGI  => 'Koji Takiguchi',
+    KOJIRO    => 'Kojiro ONO',
     KOJUN     => 'Kojun Ueno',
     KOKOGIKO  => 'OHTSUKA Ko-hei',
     KOMORIYA  => 'Kazunari Komoriya',
+    KONBOI    => 'Ryosuke Yabuki',
     KONDO     => 'Yoshiyuki KONDO',
     KOPUG     => 'Masahiro Funakoshi',
     KOSEI     => 'Kosei Moriyama',
@@ -267,6 +272,7 @@ use Acme::CPANAuthors::Register (
     MAHITO    => 'Hogelist',
     MAIDO     => 'Masahiro Funakoshi',
     MAKAMAKA  => 'Makamaka Hannyaharamitu',
+    MAKOT     => 'Makoto Nozaki',
     MAKOTO    => 'Shin Honda',
     MALA      => 'ma la',
     MAND      => 'Yuki Manno',
@@ -281,11 +287,13 @@ use Acme::CPANAuthors::Register (
     MASARTZ   => 'Masaru Hoshino',
     MASASHI   => 'masashi ogawa',
     MASASUZU  => 'SUZUKI Masashi',
+    MASAWADA  => 'Masayoshi Wada',
     MASH      => 'Masakazu Ohtsuka',
     MASIUCHI  => 'Masahiro Iuchi',
     MASUTARO  => 'Kotaro MASUDA',
     MATSUMOTO => 'syushi matsumoto',
     MATTN     => 'Yasuhiro Matsumoto',
+    MATZ      => 'Taichi Matsumura',
     MERU      => 'meru_akimbo',
     MIHYAERU  => 'Atsushi Takano',
     MIKAGE    => 'SANO Taku',
@@ -312,6 +320,7 @@ use Acme::CPANAuthors::Register (
     MUGIFLY   => 'Masanori Ohgita',
     MURATA    => 'Shingo Murata',
     MURATAYA  => 'MURATA Yasuhisa',
+    MUTO      => 'Nao Muto',
     MUYOSHI   => 'Mutsutoshi Yoshimoto',
     MYB       => 'Masayuki Iwai',
     MYFINDER  => 'TatsuroHisamori',
@@ -350,6 +359,7 @@ use Acme::CPANAuthors::Register (
     NTAKANASI => 'Nao Takanashi',
     NTSUTSUMI => 'Naoya Tsutsumi',
     NUKOSUKE  => 'nuko suke',
+    NUKOTANU  => 'Yoshiyasu Katayama',
     NYAGAO    => 'Takahiro Nagao',
     NYARLA    => 'Naoki Okamura',
     OCEORA    => 'eisaku ando',
@@ -363,6 +373,7 @@ use Acme::CPANAuthors::Register (
     OKLAHOMER => 'Go Hagiwara',
     ONISHI    => 'Yasuhiro Onishi',
     OPPARA    => 'oppara',
+    OSDAKIRA  => 'Akira Osada',
     OUEST     => 'Daisuke NISHISAKA',
     OVERLAST  => 'Toshinori Sato',
     OYAMA     => 'Hiroyuki OYAMA',
@@ -377,6 +388,7 @@ use Acme::CPANAuthors::Register (
     POCKET    => 'Masato Sogame',
     POKUTUNA  => 'POKUDA Tunahiko',
     POPPEN    => 'Shinsuke Matsui',
+    PROGRHYME => 'IKEDA Kiyoshi',
     PUNYTAN   => 'punipuni',
     QAZXSWEDC => 'hiroshi morimoto',
     QBTCFAHX  => 'Naoki SUDA',
@@ -384,6 +396,7 @@ use Acme::CPANAuthors::Register (
     RIMFS     => 'Yuichiro Tanaka',
     RINSATO   => 'takashi sato',
     RINTARO   => 'Rintaro Ishizaki',
+    RISOU     => 'Masaaki FUJISAWA',
     RITOU     => 'Ryo Ito',
     RIYWO     => 'Ryosuke IWANAGA',
     ROCKBONE  => 'Tooru Tsurukawa',
@@ -413,6 +426,7 @@ use Acme::CPANAuthors::Register (
     SEYN      => 'Yasushi Nakajima',
     SHARADA   => 'Seiji Harada',
     SHARP     => 'Motoki Kondo',
+    SHEERCAT  => 'tomoo amano',
     SHIBAZAKI => 'Yuki Shibazaki',
     SHIBUYA   => 'Kazuhiro Shibuya',
     SHIGETA   => 'Takatsugu Shigeta',
@@ -437,6 +451,7 @@ use Acme::CPANAuthors::Register (
     SKONNO    => 'Satoshi Konno',
     SKUBOTA   => 'Satoshi KUBOTA',
     SKYFIVE   => 'Takeshi Ohishi',
+    SMOMOT    => 'Seiji Momoto',
     SNGJOKEN  => 'Shingo Kikugawa',
     SNUMANO   => 'Shugo Numano',
     SOENO     => 'Kazumichi Soeno',
@@ -482,9 +497,11 @@ use Acme::CPANAuthors::Register (
     TAKESHIGE => 'Ken Takeshige',
     TAKESHUN  => 'Shun Takeyama',
     TAKIMO    => 'Shinya Takimoto',
+    TAKITAHA  => 'Takeshi Kitahara',
     TAKKYUN   => 'Takayuki Ikeda',
     TAKUJI    => 'Nishibayashi Takuji',
     TAKUMI    => 'Takumi Hayashi',
+    TAKUYAA   => 'Takuya Asano',
     TAMAKOTO  => 'Tanaka Makoto',
     TAMASHIRO => 'Yuji Tamashiro',
     TANABE    => 'Hisao Tanabe',
@@ -499,6 +516,7 @@ use Acme::CPANAuthors::Register (
     TATSUYAGI => 'Tatsuya Yagi',
     TAWAN     => 'Taro Funaki',
     TEBORA    => 'Issei Horie',
+    TENMIHI   => 'Kenichi Murao',
     THORIKAWA => 'Takahiro Horikawa',
     TISHIDUKA => 'Takeshi ISHIDUKA',
     TITSUKI   => 'Itsuki Toyota',
@@ -507,6 +525,7 @@ use Acme::CPANAuthors::Register (
     TMITOH    => 'Tomoaki Itoh',
     TMITZ     => 'Tomohiro Mitsumune',
     TNAGA     => 'Tomohide Nagasima',
+    TNANBA    => 'NANBA Toshiaki',
     TNISHINO  => 'Taro Nishino',
     TOAMANO   => 'Tomoo Amano',
     TOCIYUKI  => 'MIZUTANI, Tociyuki',
@@ -515,7 +534,9 @@ use Acme::CPANAuthors::Register (
     TOKUBASS  => 'Kouji Tominaga',
     TOKUHIROM => 'MATSUNO Tokuhiro',
     TOMBO     => 'Tomoaki Otsuka',
+    TOMCHA    => 'Tomokazu Mishima',
     TOMITA    => 'Naoki Tomita',
+    TOMOYUKI  => 'tomoyuki okino',
     TOMYHERO  => 'Tomohiro Teranishi',
     TONODERA  => 'Takahiro Onodera',
     TOONA     => 'Naoto Ishikawa',
@@ -550,9 +571,13 @@ use Acme::CPANAuthors::Register (
     VPAM      => 'singo suda',
     WADACHI   => 'Satoshi Wada',
     WAKAPON   => 'ASANO Kazunari',
+    WANIJI    => 'Makoto Sasaki',
     WATA      => 'Kouji Watanabe',
     WATANABE  => 'WATANABE Hirofumi',
+    WHISKYSHU => 'Shunsuke Usuki',
+    WHYWAITA  => 'Nakanishi Kento',
     WOREMACX  => 'Wore Macx',
+    WORTHMINE => 'Yuki Yoshida',
     XAICRON   => 'Yuji Shimada',
     XCEZX     => 'Tsuyoshi Maekawa',
     XOR       => 'Izumi Kawashima',
